==> goods-center-api-2.8.62-sources.jar: cn/com/duiba/goods/center/api/request/equity/GoodsRecordFindPageConditions.java <==
package cn.com.duiba.goods.center.api.request.equity;


import cn.com.duiba.goods.center.api.remoteservice.enums.EquityExchangeStatusEnum;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @program: goods-center-all
 * @description: 权益兑换码记录分页查询条件
 * @author: Simba
 * @create: 2019-07-09 15:35
 **/
public class GoodsRecordFindPageConditions implements Serializable {

    private static final long serialVersionUID = 9211450202841314805L;
    private Long appId;

    private List<Long> equityIdList;

    private String code;

    private EquityExchangeStatusEnum statusEnum;

    private Date startTime;

    private Date endTime;

    private Integer offset;

    private Integer max;

    private Long merchantId;

    private Long cid;

    public Long getCid() {
        return cid;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getEquityIdList() {
        return equityIdList;
    }

    public void setEquityIdList(List<Long> equityIdList) {
        this.equityIdList = equityIdList;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public EquityExchangeStatusEnum getStatusEnum() {
        return statusEnum;
    }

    public void setStatusEnum(EquityExchangeStatusEnum statusEnum) {
        this.statusEnum = statusEnum;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
}

==> goods-center-api-2.11.13-20230509.070934-3-sources.jar: cn/com/duiba/goods/center/api/request/equity/GoodsRecordFindPageConditions.java <==
package cn.com.duiba.goods.center.api.request.equity;


import cn.com.duiba.goods.center.api.remoteservice.enums.EquityExchangeStatusEnum;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @program: goods-center-all
 * @description: 权益兑换码记录分页查询条件
 * @author: Simba
 * @create: 2019-07-09 15:35
 **/
public class GoodsRecordFindPageConditions implements Serializable {

    private static final long serialVersionUID = 9211450202841314805L;
    private Long appId;

    private List<Long> equityIdList;

    private String code;

    private EquityExchangeStatusEnum statusEnum;

    private Date startTime;

    private Date endTime;

    private Integer offset;

    private Integer max;

    private Long merchantId;

    private Long cid;

    private Long stationId;

    public Long getStationId() {
        return stationId;
    }

    public void setStationId(Long stationId) {
        this.stationId = stationId;
    }

    public Long getCid() {
        return cid;
    }

    public void setCid(Long cid) {
        this.cid = cid;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getEquityIdList() {
        return equityIdList;
    }

    public void setEquityIdList(List<Long> equityIdList) {
        this.equityIdList = equityIdList;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public EquityExchangeStatusEnum getStatusEnum() {
        return statusEnum;
    }

    public void setStatusEnum(EquityExchangeStatusEnum statusEnum) {
        this.statusEnum = statusEnum;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
}
